@@ -30,7 +30,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
         learn.save(baseModel)
         if not os.path.exists(outputPath):
             os.makedirs(outputPath)
-        shutil.copy(path+os.sep+'models'+os.sep+baseModel+'.pth',outputPath)
+        shutil.copy(path+os.sep+'models'+os.sep+baseModel+'.pth',outputPath+os.sep+'base_'+baseModel+'.pth')
 
         # supervised method
         plainSupervised(path,pathUnlabelled,learn,confidence)
@@ -49,7 +49,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
         learn2.save(targetModel)
-        shutil.copy(path+os.sep+'models' + os.sep + targetModel + '.pth', outputPath)
+        shutil.copy(path+'_tmp'+os.sep+'models' + os.sep + targetModel + '.pth', outputPath+os.sep+'target_'+baseModel+'.pth')
         shutil.rmtree(path+'_tmp')
 
 
@@ -77,7 +77,10 @@ def dataDistillation(baseModel, targetModel, transforms, path, pathUnlabelled, o
 
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
-        learn.save(outputPath + os.sep + baseModel)
+        learn.save(baseModel)
+        if not os.path.exists(outputPath):
+            os.makedirs(outputPath)
+        shutil.copy(path+os.sep+'models'+os.sep+baseModel+'.pth',outputPath+os.sep+'base_'+baseModel+'.pth')
 
         # supervised method
         omniData(path, pathUnlabelled, learn, transforms,confidence)
@@ -95,7 +98,9 @@ def dataDistillation(baseModel, targetModel, transforms, path, pathUnlabelled, o
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.save(outputPath + os.sep + targetModel)
+        learn2.save(targetModel)
+        shutil.copy(path + '_tmp' + os.sep + 'models' + os.sep + targetModel + '.pth',
+                    outputPath + os.sep + 'target_' + baseModel + '.pth')
         shutil.rmtree(path + '_tmp')
 
 
@@ -125,9 +130,14 @@ def modelDistillation(baseModels, targetModel, path, pathUnlabelled, outputPath,
 
             # Train base learner
             learn.fine_tune(50, freeze_epochs=2)
-            learn.save(outputPath + os.sep + baseModel)
+            learn.save(baseModel)
+            if not os.path.exists(outputPath):
+                os.makedirs(outputPath)
+            shutil.copy(path + os.sep + 'models' + os.sep + baseModel + '.pth',
+                        outputPath + os.sep + 'base_' + baseModel + '.pth')
             learners.append(learn)
 
+
         # supervised method
         omniModel(path, pathUnlabelled, learners, confidence)
 
@@ -144,7 +154,9 @@ def modelDistillation(baseModels, targetModel, path, pathUnlabelled, outputPath,
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.save(outputPath + os.sep + targetModel)
+        learn2.save(targetModel)
+        shutil.copy(path + '_tmp' + os.sep + 'models' + os.sep + targetModel + '.pth',
+                    outputPath + os.sep + 'target_' + baseModel + '.pth')
         shutil.rmtree(path + '_tmp')
 
 
@@ -175,7 +187,11 @@ def modelDataDistillation(baseModels, targetModel, transforms, path, pathUnlabel
 
             # Train base learner
             learn.fine_tune(50, freeze_epochs=2)
-            learn.save(outputPath + os.sep + baseModel)
+            learn.save(baseModel)
+            if not os.path.exists(outputPath):
+                os.makedirs(outputPath)
+            shutil.copy(path + os.sep + 'models' + os.sep + baseModel + '.pth',
+                        outputPath + os.sep + 'base_' + baseModel + '.pth')
             learners.append(learn)
 
         # supervised method
@@ -194,5 +210,7 @@ def modelDataDistillation(baseModels, targetModel, transforms, path, pathUnlabel
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.save(outputPath + os.sep + targetModel)
+        learn2.save(targetModel)
+        shutil.copy(path + '_tmp' + os.sep + 'models' + os.sep + targetModel + '.pth',
+                    outputPath + os.sep + 'target_' + baseModel + '.pth')
         shutil.rmtree(path + '_tmp')
